summaryrefslogtreecommitdiffstats
path: root/tests/integration/repo_fork_test.go
diff options
context:
space:
mode:
Diffstat (limited to 'tests/integration/repo_fork_test.go')
-rw-r--r--tests/integration/repo_fork_test.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/tests/integration/repo_fork_test.go b/tests/integration/repo_fork_test.go
index 26c81f5bee..594fba6796 100644
--- a/tests/integration/repo_fork_test.go
+++ b/tests/integration/repo_fork_test.go
@@ -63,10 +63,10 @@ func TestRepoFork(t *testing.T) {
func TestRepoForkToOrg(t *testing.T) {
defer tests.PrepareTestEnv(t)()
session := loginUser(t, "user2")
- testRepoFork(t, session, "user2", "repo1", "user3", "repo1")
+ testRepoFork(t, session, "user2", "repo1", "org3", "repo1")
// Check that no more forking is allowed as user2 owns repository
// and user3 organization that owner user2 is also now has forked this repository
req := NewRequest(t, "GET", "/user2/repo1")
resp := session.MakeRequest(t, req, http.StatusOK)
htmlDoc := NewHTMLParser(t, resp.Body)
@@ -63,10 +63,10 @@ func TestRepoFork(t *testing.T) {
// Check that no more forking is allowed as user2 owns repository
- // and user3 organization that owner user2 is also now has forked this repository
+ // and org3 organization that owner user2 is also now has forked this repository
req := NewRequest(t, "GET", "/user2/repo1")
resp := session.MakeRequest(t, req, http.StatusOK)